@@ -1,7 +1,11 @@
 import numpy
 import xarray
 import matplotlib.pyplot as plt
+from configparser import ConfigParser
 
+file = 'lazyearth.ini'
+config = ConfigParser()
+config.read(file)
 
 class objearth():
     def __init__(self,DataArray):
@@ -54,8 +58,10 @@ class objearth():
             print("Nonetype :",type(self.DataArray))
             
     def NDVI(self):
-        red = xarray.where(self.DataArray.red==-9999,numpy.nan,self.DataArray.red)
-        nir = xarray.where(self.DataArray.nir==-9999,numpy.nan,self.DataArray.nir)
+        Nodata = int(config['Data']['Nodata'])
+        fractionconstant = float(config['Plot']['fractionnumber'])
+        red = xarray.where(self.DataArray.red==Nodata,numpy.nan,self.DataArray.red)
+        nir = xarray.where(self.DataArray.nir==Nodata,numpy.nan,self.DataArray.nir)
         ndvi1 = (nir-red)/(nir+red).to_numpy()
         ndvi3 = numpy.clip(ndvi1,-1,1)
         im_ratio = ndvi3.shape[1]/ndvi3.shape[0]
@@ -63,13 +69,14 @@ class objearth():
         plt.xticks([]), plt.yticks([])
         plt.imshow(ndvi3,cmap='viridis')
         plt.clim(-1,1)
-        plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
+        plt.colorbar(orientation="vertical",fraction=fractionconstant*im_ratio)
         plt.show()
         return ndvi3
 
     def percentcloud(self,Dataset):
+        Cloud = (config['Cloud']['Fashcloud'])
         self.Dataset = Dataset
-        FashCloud = [352,480,944]
+        FashCloud = Cloud
         dstest    = self.Dataset.pixel_qa
         dsnew     = xarray.where(dstest == FashCloud[0],numpy.nan,dstest)
         dsnew     = xarray.where(dsnew  == FashCloud[1],numpy.nan,dsnew)
